/*
  This implementation specific to Maple Mini and used with a NOKIA 5110 Graphic LCD.
    Compiled under Arduino 1.8.6 on Linux Mint 18.3 Cinnamon tested 20180921
      Sketch uses 18844 bytes (15%) of program storage space. Maximum is 122880 bytes.
      Global variables use 3280 bytes (16%) of dynamic memory, leaving 17200 bytes for local variables. Maximum is 20480 bytes.
*/

#include <Streaming.h>                   // http://arduiniana.org/libraries/streaming/
#include "Defines.h"                     // Nokia 5110 LCD electrical connections

// constants
const int       BAUD        = 115200;    // rPi3B defaults to 115200
const byte      ContrastPin = 8;         // D8 low activates the Contrast adjustment
const unsigned long FiveSec = 5000 ;     // do something every 5 seconds

// global prog variables
byte          nRow;                      // line count      (0- 5 for NOKIA LCD)
byte          nColumn;                   // character count (0-11 for NOKIA LCD)
byte          NOKIAcontrast = 0xBE;      // LCD initialization contrast values B0 thru BF
boolean       mute;                      // mute volume / stop mpc
unsigned int  Channels      = 10;        // How many channels are stored?
unsigned int  CurrentChnl   = 1;         // channnel playing; eg: 1, 2, ... 9, 10
unsigned int  OldChannel    = 1;
uint8_t       paddleX ;                  // Value to represent station selection
uint8_t       paddleY ;                  // Value to represent volume
uint8_t       previousX ;
uint8_t       previousY ;
unsigned long TimeMarker;                // Software variable for creating an event

char          temp;
char*         BlankLine[]   = {"            "};  // Nokia 12 x 6 (84 * 48)

// Character array pointers - message and command table
const char*         msg0[]        = {"mpc clear;mpc add http://"};   // prefix
const char*         msg1[]        = {";mpc play;sleep 1;mpc play"};  // suffix
const char*         msg2[]        = {"71.125.37.66:7000"};       // Rewound Radio:
const char*         msg3[]        = {"206.190.136.212:7744"};    // Classic Hits JFRC
const char*         msg4[]        = {"64.78.234.173:8528"};
const char*         msg5[]        = {"204.141.167.19:9170"};
const char*         msg6[]        = {"198.178.123.17:10922"};    // San Francisco's 70's HITS!
const char*         msg7[]        = {"91.121.155.204:8048"};     // 1000 HITS 80s
const char*         msg8[]        = {"45.79.186.124:8160"};      // Personal Favorites 60s/70s/80s/90s/More
const char*         msg9[]        = {"51.15.152.81:8085"};
const char*         msg10[]       = {"198.58.98.83:8062"};       // Bulldogs-Radio:
const char*         msg11[]       = {"50.7.129.122:8433"};       // Flower Power Radio - Far Out And Groovy Tunes From The 50's 60's & 70's
const char*         msg12[]       = {""};
const char*         msg13[]       = {""};
const char*         msg14[]       = {""};
const char*         msg15[]       = {""};
const char*         msg16[]       = {""};
const char*         msg17[]       = {""};
const char*         msg18[]       = {""};
const char*         msg19[]       = {""};
const char*         msg20[]       = {""};
const char*         msg21[]       = {"mpc play"};
const char*         msg22[]       = {"mpc stop"};
const char*         msg23[]       = {"sudo reboot now"};
const char*         msg24[]       = {"mpc volume +5"};
const char*         msg25[]       = {"mpc volume -5"};
const char*         msg26[]       = {"sudo reboot now"};


void setup(void)
{
  pinMode(ContrastPin, INPUT);
  digitalWrite(ContrastPin, HIGH);       // activate internal pullup resistor
  pinMode(JoyButton, INPUT);             // "Key"
  pinMode(PinInX, INPUT_ANALOG);         // X potentiometer
  pinMode(PinInY, INPUT_ANALOG);         // Y potentiometer

  Serial1.begin(BAUD);

  LcdInitialise();
  LcdClear();
  delay(100);
  previousX = Joystick_X();              // capture centerpoint X null
  previousY = Joystick_Y();              // capture centerpoint Y null
  Serial1 << endl;                       // CR+LF to rPi serial console

  TimeMarker = millis();                 // variable to implement function timing events
}


void loop(void)
{
  IsMute();
  AdjustVolume();
  ChangeChannel();
  SerialInput();
  ForceUpdate();
}
