// UtilFuncts.ino

int Joystick_X()  {
  uint8_t x;
  // map                ( value, fromLow, fromHigh, toLow, toHigh) ;  // Label V
  x = map(   analogRead(PinInX),       0,     1023,     1,     20) ;  // Analog D11 == PA0/CH0
  return ( x) ;                                                       // Volume +/-

}

int Joystick_Y()  {
  uint8_t y;
  // map                ( value, fromLow, fromHigh, toLow, toHigh) ;  // Label H
  y = map(   analogRead(PinInY),       0,     1023,     1,     20) ;  // Analog D10 == PA1/CH1
  return ( y) ;                                                       // Channel +/-
}

boolean UserButtonInput() {
  return digitalRead(JoyButton);     // joystick button on D12 of Maple Mini
}

void IsMute( void )  {
  mute = ! UserButtonInput();
  if( mute ) {
    Serial1 << msg22[0] << endl;     // mpc stop
    LcdClear(); gotoXY(2, 1); LcdString("MUTE is On");
    gotoXY(0, 5); LcdString( BlankLine[0] ); gotoXY(0, 5); dispcountt( CurrentChnl ); LcdString(" :Channel");
    delay(1000);
    do {delay(50);} while ( abs(Joystick_X() - previousX) < 5 );
    mute = false;
    LcdClear();
    Serial1 << msg21[0] << endl;     // mpc play
  }
}

boolean AdjustVolume( void )  {
  if( Joystick_X() > previousX + 5 ) {
    Serial1 << msg24[0] << endl;
    delay(500);
  } else if (Joystick_X() < previousX - 5 ) {
    Serial1 << msg25[0] << endl;
    delay(500);
  } return true;
}

boolean ChangeChannel( void ) {
  OldChannel = CurrentChnl;
  if( Joystick_Y() > previousY + 5 ) {
    ++CurrentChnl;
    if(CurrentChnl > 10) CurrentChnl = 1;
    delay(500);
  } else if (Joystick_Y() < previousY - 5 ) {
    CurrentChnl--;
    TimeMarker = FiveSec + millis();
    delay(500);
    if(CurrentChnl < 1) CurrentChnl = 1;
    do  {
      delay(500);
    } while ( Joystick_Y() < previousY - 5 ) ;
        if (TimeMarker < millis() ) {
          Serial1 << msg26[0] << endl; // force reboot if control held > 5 seconds
          LcdClear();
          delay(100);
          gotoXY(2, 1); LcdString("REBOOTING...");
        }
  }

  if (CurrentChnl != OldChannel)  {
    gotoXY(0, 5); LcdString( BlankLine[0] ); gotoXY(0, 5); dispcountt( CurrentChnl ); LcdString(" :Channel");
    ChannelChanger(CurrentChnl);
    TimeMarker = millis() - 6000;  // Force songtitle update
    OldChannel = CurrentChnl;
  }
  return true;
}

void SerialInput( void ) {
  // extract the song title and display it on the LCD
  if (Serial1.available() > 0) {         // anything in the serial hw buffer?
    char temp = Serial1.read();          // if so, fetch the next character from FIFO
    SongTitle(temp);                     // Parse the Artist+Title
  }
}

void ForceUpdate( void ) {
  // Every 5 seconds force update of mpc to extract current song info
  if ((TimeMarker + FiveSec) < millis() ) {
    TimeMarker = millis();
    Serial1 << msg21[0] << endl;         // refresh the display using "mpc play"
  }
}

void SongTitle(char c) {
  static int i, j;
  static char q;
  static bool flag = false, flag1 = true;
  static char Titlebuffer[72];
  q = c;

  if ( q == 0x24) // '$' last line in "mpc play" command
  {
    // Serial << "found $ setting flag false" << endl;
    i = 0;
    flag1 = false;                    // 1st key double-lock for LCD output
    flag = false;                     // 2nd key ... we want first line info on next "mpc play"
  }

  if (q == 0x3a) {                    // ':'
    flag = true;                      // song title capture enabled on 1st line
    // Serial << "found ':' setting flag true" << endl;
    i = 0;
  }

  if (flag && !flag1) {               // double-lock
    if (i < 72) Titlebuffer[i++] = q; // auto increment index
      
    if ( q == 0x0a || q == 0x0d )     // CR or LF? End of line capture
    {
      flag1 = true;                   // stay out of spooler until next '$'
      LcdClear(); gotoXY(0, 5); LcdString( BlankLine[0] ); gotoXY(0, 5); dispcountt( CurrentChnl );
                                LcdString(" :Channel"); gotoXY(0, 0);
      for (j = 2; j < i-1 ; j++) {    // [0],[1] == space, display song title [1]...[n]
        if (Titlebuffer[j] == 0x0d || Titlebuffer[j] == 0x0a) exit; // end of 1st line
        delay(25);                    // necessary for slow Nokia
        LcdCharacter(Titlebuffer[j]);
        if (Titlebuffer[j] == '-') { gotoXY(0, (nRow + 2)); ++j;}   // force linebreak before song title
      }
      flag = false;                   // close second lock until '$' in stream
    }
  }
}


void ChannelChanger(int chnl)
{
  Serial1 << msg0[0];                 // prefix

  switch (chnl) 
  {
    case 1:
      Serial1 << msg2[0];
      break;
    case 2:
      Serial1 << msg3[0];
      break;
    case 3:
      Serial1 << msg4[0];
      break;
    case 4:
      Serial1 << msg5[0];
      break;
    case 5:
      Serial1 << msg6[0];
      break;
    case 6:
      Serial1 << msg7[0];
      break;
    case 7:
      Serial1 << msg8[0];
      break;
    case 8:
      Serial1 << msg9[0];
      break;
    case 9:
      Serial1 << msg10[0];
      break;
    case 10:
      Serial1 << msg11[0];
      break;
    default:
      Serial1 << msg5[0];
      break;
  }
  Serial1 << msg1[0] << endl;         // suffix
}
